﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UIElements;

public class PlayerController : MonoBehaviour
{
    public GameManager m_gameManager;
    Rigidbody2D m_rigidbody;
    public Animator m_animator;
    BoxCollider2D m_boxColider;
    SpriteRenderer m_renderer;
    SpriteRenderer m_health1;
    SpriteRenderer m_health2;
    SpriteRenderer m_health3;
    ItemManager m_items;

    float m_horizontalMovement;
    public bool m_isFlying = false;
    public float m_moveSpeed = 5;
    float m_flapTime = 0.5f;
    public float m_health;
    float m_invincibility;

    // Start is called before the first frame update
    void Start()
    {
        m_rigidbody = GetComponent<Rigidbody2D>();
        m_animator = GetComponent<Animator>();
        m_boxColider = GetComponent<BoxCollider2D>();
        m_renderer = GetComponent<SpriteRenderer>();

        GameObject health1 = GameObject.Find("Health1");
        GameObject health2 = GameObject.Find("Health2");
        GameObject health3 = GameObject.Find("Health3");
        GameObject items = GameObject.Find("Items");

        m_health1 = health1.GetComponent<SpriteRenderer>();
        m_health2 = health2.GetComponent<SpriteRenderer>();
        m_health3 = health3.GetComponent<SpriteRenderer>();
        m_items = items.GetComponent<ItemManager>();

        m_health = 3;
        DrawHealth();
    }

    // Update is called once per frame
    void Update()
    {
        if (!m_gameManager.m_isPaused)
        {
            if (Input.GetKeyDown(KeyCode.Escape))
            {
                m_gameManager.PauseGame();
            }

            Movement();
            CheckFlying();
            Invincibility();
        }
        else
        {
            if (Input.GetKeyDown(KeyCode.Escape))
            {
                m_gameManager.UnpauseGame();
            }
        }
    }

    void FixedUpdate()
    {
        m_horizontalMovement = Input.GetAxisRaw("Horizontal");

        m_rigidbody.velocity = new Vector2(m_horizontalMovement * m_moveSpeed, 0);
    }

    void Movement()
    {
        if (Input.GetKey(KeyCode.A) || (Input.GetKey(KeyCode.D)))
        {
            m_moveSpeed = 2;
        }
        else
        {
            m_moveSpeed = 0;
        }

        if (Input.GetKey(KeyCode.W) && !m_isFlying)
        {
            m_isFlying = true;
            m_flapTime = 0.25f;
            m_rigidbody.gravityScale = -20;
            m_animator.SetBool("Flapping", true);
        }
        else if (Input.GetKey(KeyCode.S) && !m_isFlying)
        {
            m_rigidbody.gravityScale = 15;
        }
        else
        {
            if (!m_isFlying)
            {
                m_rigidbody.gravityScale = 5;
            }
        }
    }

    void CheckFlying()
    {
        if (m_isFlying)
        {
            if (m_flapTime > 0)
            {
                m_flapTime -= Time.deltaTime;
            }
            else
            {
                m_animator.SetBool("Flapping", false);
                m_isFlying = false;
            }
        }
    }

    void OnTriggerEnter2D(Collider2D other)
    {
        if (other.gameObject.tag == "Enemy")
        {
            TakeDamage();
        }
        if (other.gameObject.tag == "Item")
        {
            m_items.CollectItem();
        }
    }

    void TakeDamage()
    {
        m_health--;
        m_invincibility = 1;

        DrawHealth();
        CheckDeath();
    }

    void Invincibility()
    {

        if (m_invincibility > 0)
        {
            m_invincibility -= Time.deltaTime;
            m_boxColider.enabled = false;
            Flicker();
        }
        else
        {
            m_renderer.enabled = true;
            m_boxColider.enabled = true;
        }
    }

    void Flicker()
    {
        if (m_renderer.enabled == false)
        {
            m_renderer.enabled = true;
        }
        else
        {
            m_renderer.enabled = false;
        }
    }

    public void DrawHealth()
    {
        if (m_health >= 3)
        {
            m_health1.enabled = true;
            m_health2.enabled = true;
            m_health3.enabled = true;
        }
        else if (m_health == 2)
        {
            m_health1.enabled = true;
            m_health2.enabled = true;
            m_health3.enabled = false;
        }
        else if (m_health == 1)
        {
            m_health1.enabled = true;
            m_health2.enabled = false;
            m_health3.enabled = false;
        }
        else
        {
            m_health1.enabled = false;
            m_health2.enabled = false;
            m_health3.enabled = false;
        }
    }

    void CheckDeath()
    {
        if (m_health<=0)
        {
            //Time.timeScale = 0; // only until I figure out how to change scenes
            /*game over screen
            if score == hiscore then go to hiscore screen */
        }
    }
}
